from __future__ import annotations

from typing import List

from pydantic import Field

from locatieserver.schema.base import LocatieserverBaseModel
from locatieserver.schema.utils import Point


class FreeDoc(LocatieserverBaseModel):
    """Free service document"""

    bron: str
    woonplaatscode: str
    type: str
    woonplaatsnaam: str
    huis_nlt: str
    openbareruimtetype: str
    gemeentecode: str
    weergavenaam: str
    straatnaam_verkort: str
    id: str
    gemeentenaam: str
    identificatie: str
    openbareruimte_id: str
    provinciecode: str
    postcode: str
    provincienaam: str
    centroide_ll: Point
    nummeraanduiding_id: str
    adresseerbaarobject_id: str
    huisnummer: int
    provincieafkorting: str
    centroide_rd: Point
    straatnaam: str
    gekoppeld_perceel: List[str]
    score: float


class FreeInlineResponse(LocatieserverBaseModel):
    num_found: int = Field(..., alias="numFound")
    start: int
    max_score: float = Field(..., alias="maxScore")
    docs: List[FreeDoc]


class FreeResponse(LocatieserverBaseModel):
    """Response for the free service"""

    response: FreeInlineResponse



from pydantic import BaseModel, Field
from pydantic.json import pydantic_encoder

from locatieserver.schema.free import FreeResponse
from locatieserver.schema.lookup import LookupResponse
from locatieserver.schema.suggest import SuggestResponse


class OpenAPI(BaseModel):
    suggest_response: SuggestResponse = Field(..., alias="SuggestResponse")
    free_response: FreeResponse = Field(..., alias="FreeResponse")
    lookup_response: LookupResponse = Field(..., alias="LookupResponse")


if __name__ == "__main__":

    x = OpenAPI.schema(ref_template="#/components/schemas/{model}")

    y = OpenAPI.__config__.json_dumps(x["definitions"], default=pydantic_encoder, indent=2)
    print(y)



from __future__ import annotations

from typing import List, Optional

from pydantic import Field

from locatieserver.schema.base import LocatieserverBaseModel
from locatieserver.schema.utils import Point


class LookupDoc(LocatieserverBaseModel):
    """Lookup service document"""

    bron: Optional[str]
    woonplaatscode: Optional[str]
    type: Optional[str]
    woonplaatsnaam: Optional[str]
    huis_nlt: Optional[str]
    openbareruimtetype: Optional[str]
    gemeentecode: Optional[str]
    weergavenaam: Optional[str]
    straatnaam_verkort: Optional[str]
    id: Optional[str]
    gemeentenaam: Optional[str]
    identificatie: Optional[str]
    openbareruimte_id: Optional[str]
    provinciecode: Optional[str]
    postcode: Optional[str]
    provincienaam: Optional[str]
    centroide_ll: Optional[Point]
    nummeraanduiding_id: Optional[str]
    adresseerbaarobject_id: Optional[str]
    huisnummer: Optional[int]
    huisnummertoevoeging: Optional[str] = ""
    huisletter: Optional[str] = ""
    provincieafkorting: Optional[str]
    centroide_rd: Optional[Point]
    straatnaam: Optional[str]
    gekoppeld_perceel: Optional[List[str]]


class LookupInlineResponse(LocatieserverBaseModel):
    num_found: int = Field(..., alias="numFound")
    start: int
    docs: List[LookupDoc]


class LookupResponse(LocatieserverBaseModel):
    """Response for the lookup service"""

    response: LookupInlineResponse



"""API methods of the locatieserver grouped in this module for clean imports."""


from .free import free
from .lookup import lookup
from .suggest import suggest

__all__ = ["free", "lookup", "suggest"]



from __future__ import annotations

from typing import Dict, List, Union

from pydantic import Field

from locatieserver.schema.base import LocatieserverBaseModel


class SuggestDoc(LocatieserverBaseModel):
    type: str
    weergavenaam: str
    id: str
    score: float


class SuggestInlineResponse(LocatieserverBaseModel):
    num_found: int = Field(..., alias="numFound")
    start: int
    max_score: float = Field(..., alias="maxScore")
    docs: List[SuggestDoc]


class Suggest(LocatieserverBaseModel):
    suggest: List[str]


class Suggestion(LocatieserverBaseModel):
    num_found: int = Field(..., alias="numFound")
    start_offset: int = Field(..., alias="startOffset")
    end_offset: int = Field(..., alias="endOffset")
    suggestion: List[str]


class Collation(LocatieserverBaseModel):
    collation_query: str = Field(..., alias="collationQuery")
    hits: int
    misspellings_and_corrections: List[str] = Field(..., alias="misspellingsAndCorrections")


class Spellcheck(LocatieserverBaseModel):
    suggestions: List[Union[str, Suggestion]]
    collations: List[Union[str, Collation]]


class SuggestResponse(LocatieserverBaseModel):
    """Response for the suggest service"""

    response: SuggestInlineResponse
    highlighting: Dict[str, Suggest]
    spellcheck: Spellcheck


if __name__ == "__main__":
    x = SuggestResponse.schema_json()

    print(x)
